##############################################################################
#
# SessionUserFolder - A session-based user folder
# Copyright (c) 2002 Levente Sndor. All rights reserved.
# 
##############################################################################
''' Session-based User Folder '''


import base64, string
from AccessControl.ZopeSecurityPolicy import _noroles
from AccessControl.User import UserFolder
from AccessControl import getSecurityManager
from Globals import InitializeClass
from OFS.DTMLMethod import DTMLMethod

class SessionUserFolder(UserFolder):
    ''' Session-based User Folder '''
    
    meta_type = 'User Folder (session-based)'
    title = 'Session-based User Folder'

    def validate(self, request, auth='', roles=_noroles):
        ''' Session-based validation '''
        
        session = request.SESSION

        if request.has_key('__logout__'):
            try:
                del session['__auth__']
            except: pass
        elif not auth:
            try:
                auth = session['__auth__']
            except:
                try:
                    auth = 'Basic ' + base64.encodestring(
                        '%s:%s' % (request['__name__'], request['__password__']))
                except: pass

        result = UserFolder.validate(self, request, auth, roles)
        user_folder = self

        if not result:
            for user_folder in self.superValues(('User Folder',
                                                 'User Folder (session-based)')
                                                )[1:]:
                result = user_folder.validate(request, auth, roles)
                if result:
                    break
                
        user = getSecurityManager().getUser()
        
        if user.getUserName() != 'Anonymous User':
            session['__auth__'] = auth
            
        a, c, n, v = user_folder._getobcontext(request['PUBLISHED'], request)
        if not user_folder.authorize(user, a, c, n, v, roles):
            raise 'AuthorizationRequired', 'You are not authorized to access this resource.'

        return result

InitializeClass(SessionUserFolder)


def manage_addSessionUserFolder(self, REQUEST=None):
    ''' Add a new session-based User Folder '''

    obj = SessionUserFolder()
    self = self.this()
    self._setObject(obj.getId(), obj)
    
    form_src = '''
<dtml-if expr="AUTHENTICATED_USER.getUserName() == 'Anonymous User'">
    <form action="<dtml-if QUERY_STRING>?&dtml-QUERY_STRING;</dtml-if>" method="POST">
        User name:<br>
        <input type="text" name="__name__"><br>
        Password:<br>
        <input type="password" name="__password__"><br>
        <input type="submit" value="Login">
    </form>
<dtml-else>
    <form action="%s<dtml-if QUERY_STRING>?&dtml-QUERY_STRING;</dtml-if>" method="POST">
        User: &dtml-AUTHENTICATED_USER;<br>
        <input type="submit" name="__logout__" value="Logout">
    </form>
</dtml-if>''' % string.join(self.getPhysicalPath(),'/')

    self.manage_addDTMLMethod('acl_usersLoginForm', '')
    self.acl_usersLoginForm.manage_edit(form_src, 'Login form for the Session-based User Folder')
    
    if REQUEST is not None:
        REQUEST['RESPONSE'].redirect(self.absolute_url()+'/manage_main')
